@@ -216,6 +216,11 @@ class Results_Clsf():
     def roc(self):
         if self.c!=2: raise ValueError('More than two classes')
         plot_roc(self.actuals, self.probs)
+    def get_correct(self, actual=None, n=8):
+        idx = np.where(self.actuals==self.preds)[0]
+        if actual is not None:
+            idx = [i for i in idx if self.actual[i]==actual]
+        return idx[:n]
     def get_wrong(self, actual=None, n=8):
         idx = np.where(self.actuals!=self.preds)[0]
         if actual is not None:
@@ -225,10 +230,6 @@ class Results_Clsf():
         return np.argsort(np.absolute(self.probs-.5))[::-1][:n]
     def get_least_confident(self, n=8):
         return np.argsort(np.absolute(self.probs-.5))[:n]
-    def best(self, n=8):
-        return np.argsort(self.probs)[::-1][:n]
-    def worst(self, n=8):
-        return np.argsort(self.probs)[:n]
 
 class Results_Clsf_Tabular(Results_Clsf):
     def __init__(self, data, df):
